#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.$.m..X}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}..XS.6.'.|.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.|.'.6.S..X}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}..Xm.$.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.Y.pXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXpX).q.9XtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX9Xq.).pXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXpXY.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXwXrXyXiXiXiXiXyXrXwXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXrX8XOXY.Z.m.M.A.R.@X9XrXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqX0X;XI.:.x > o O < n 2.E.>X0XqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqX0X%X1.q : O .     . + > t w.=XqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqX0X=XX.2 o .             . O 5 -.>X0XqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.%.W.dXiXiXiXiXiXiXpX9X>.8                         r 7.9XwXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXuXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXpXwXt.'.dXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXwXqXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.H _ 4.2.2.2.2.2.2.2.-.0 X                         X N ].8XwXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqX8Xg.,.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.,.F | 4.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.2.1.0.:XeXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.%.8                                                   w 0.<XeXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xg                                                                                         & }.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.%.0                                                   % F &XrXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz                                                                                         > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.%.0                                                   . u @XrXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz                                                                                         > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.%.0                                                     7 +XtXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz                                                                                         > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.%.0                                                     0 +XrXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz                                                                                         > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.%.0                                                   O z $XrXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz                                                                                         > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.%.9                                                   < { -XeXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz                                                                                         > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.%.p > 7 7 7 7 7 7 7 7 6 # .                         . h C.4XwXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               & 8 7 7 7 7 7 7 7 7 7 7 7 7 6 ; 2 8 7 7 7 7 7 7 7 7 7 7 8 :               > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&. .M.=X%X%X%X%X%X%X%X|.S %                         & E ,X0XqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               E =X%X%X%X%X%X%X%X%X%X%X%X%XoX,.G.=X%X%X%X%X%X%X%X%X%X%X:X4.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.$.T.iXrXrXrXrXrXrXrX0XI.M                     .   F E.0XqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               _ iXrXrXrXrXrXrXrXrXrXrXrXtX8Xw.).iXrXrXrXrXrXrXrXrXrXrXdXi.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqX6XV.G @                 $ I F.8XqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXwX8XL.Y               o ^ R.9XwXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXaXA..             + T.pXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.Y.iXrXrXrXrXrXrXrXrXrXrXdXS..             + R.sXrXrXrXrXrXrXrXrXrXrXrXiX).q.8XtXrXrXrXrXrXrXrXrXrXtX8Xx               ` pXrXrXrXrXrXrXrXrXrXrXrXtX8Xq.).iXrXrXrXrXrXrXrXrXrXrXdXi.              , XXpXrXrXrXrXrXrXrXrXrXrXrXiXY.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.%.i.A.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.G.;.              O 5.F.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.A.f.<.B.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.M.t               Z D.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.B.<.f.A.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.G.{               = a.D.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.A.i.%.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.%.q.k.j.j.j.j.j.j.j.j.j.j.c.O.              o =.x.j.j.j.j.j.j.j.j.j.j.j.k.r.>.g.j.j.j.j.j.j.j.j.j.j.k.d.w               m z.j.j.j.j.j.j.j.j.j.j.j.j.g.>.r.k.j.j.j.j.j.j.j.j.j.j.c./               & 7.z.j.j.j.j.j.j.j.j.j.j.j.k.q.%.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.U.yXwXwXwXwXwXwXwXwXwXwXpXZ..             + Y.iXwXwXwXwXwXwXwXwXwXwXwXyX/.q.6XeXwXwXwXwXwXwXwXwXwXeX6Xz               _ yXwXwXwXwXwXwXwXwXwXwXwXeX6Xq./.yXwXwXwXwXwXwXwXwXwXwXaXu.              >  XyXwXwXwXwXwXwXwXwXwXwXwXyXU.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz   .       .   ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xl   $ o   + %   ) yXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXwX0XoX-.a T a.D.K.C.q.B z e.:XqXwXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqX0X`.&.' a.oXlXPXUXHXsX).7.` 3.$XqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXrX X3.P /.SXUXUXUXUXUXUXUXvXC.F f.=XrXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqX9Xt.Y (.DXUXUXUXUXUXUXUXUXUXbXD.D G.qXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXwX!.+.1.DXIXUXUXUXUXUXUXUXUXUXUXlX_ 4. XeXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXeXu.&.`.UXUXUXUXUXUXUXUXUXUXUXUXDXF...Z.yXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXeXo.>.gXUXUXUXUXUXUXUXUXUXUXUXUXKX9X^ i.uXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXrXQ <.KXUXUXUXUXUXUXUXUXUXUXUXUXIXNXU 5.iXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXrXT ,.UXUXUXUXUXUXUXUXUXUXUXUXUXIXAXP 2.iXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXeX] ,.MXUXUXUXUXUXUXUXUXUXUXUXUXLXdXW w.uXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXeX3.=.;XIXUXUXUXUXUXUXUXUXUXUXUXGX].[ v.yXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXwXD.o.d.UXUXUXUXUXUXUXUXUXUXUXUXCX-.-.^.rXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqX;X2.^ 3XIXUXUXUXUXUXUXUXUXUXFXXXD x.2XwXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXyXP.} :.5XPXUXUXUXUXUXUXUXFXoXX.+.}.tXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXwX7XS.G 8.#XkXAXPXUXLXVXdX_.&.P _.8XwXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXwX4XE.Y x 2.}.eXgX8X~.| l [ {.7XqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqX6X.Xk , i p u p y & E -X8XqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXeX7Xz               _ uXwXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX5Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.Y.iXrXrXrXrXrXrXrXrXrXrXsXA..             + T.aXrXrXrXrXrXrXrXrXrXrXrXiX(.q.8XrXrXrXrXrXrXrXrXrXrXrX7Xz               _ iXrXrXrXrXrXrXrXrXrXrXrXrX8Xq.(.iXrXrXrXrXrXrXrXrXrXrXsXi.              , .XiXrXrXrXrXrXrXrXrXrXrXrXiXY.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.A.-X&X&X&X&X&X&X&X&X&X&X>Xk..             + B.>X&X&X&X&X&X&X&X&X&X&X&X-XL.8.+X&X&X&X&X&X&X&X&X&X&X*XOXh               W ;X&X&X&X&X&X&X&X&X&X&X&X&X+X8.L.-X&X&X&X&X&X&X&X&X&X&X,X5.              : E.;X&X&X&X&X&X&X&X&X&X&X&X-XA.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.,.5.4.4.4.4.4.4.4.4.4.4.8./               o [ 8.4.4.4.4.4.4.4.4.4.4.4.5.<.=.4.4.4.4.4.4.4.4.4.4.4.5.1.7               k 7.4.4.4.4.4.4.4.4.4.4.4.4.4.=.<.5.4.4.4.4.4.4.4.4.4.4.8.L               % @.7.4.4.4.4.4.4.4.4.4.4.4.5.,.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.Z.*X$X$X$X$X$X$X$X$X$X$X:Xj..             + N.;X$X$X$X$X$X$X$X$X$X$X$X*XK.7.OX%X$X$X$X$X$X$X$X$X$X%XXXg               E =X$X$X$X$X$X$X$X$X$X$X$X%XOX7.K.*X$X$X$X$X$X$X$X$X$X$X:X4.              : T.=X$X$X$X$X$X$X$X$X$X$X$X*XZ.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.Y.iXrXrXrXrXrXrXrXrXrXrXsXA..             + T.aXrXrXrXrXrXrXrXrXrXrXrXiX(.q.8XtXrXrXrXrXrXrXrXrXrXtX7Xz               _ iXrXrXrXrXrXrXrXrXrXrXrXtX8Xq.(.iXrXrXrXrXrXrXrXrXrXrXdXi.              , .XiXrXrXrXrXrXrXrXrXrXrXrXiXY.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXwXdXi.  .           : oXuXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqX8XoX@.> M J L L F g 5 b.:XqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqX7X'.#.B +.].dXZXNX9XS.R Z d.%XqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + U.uXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXwX4Xz               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqX8X|.U ..|.BXFXLXIXIXKXSXjXD.G 2.:XqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             + E.dXyXyXyXyXyXyXyXyXyXyXyXaX_.e.0XuXyXyXyXyXyXyXyXyXyXuX9Xx               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXeX=X{ &..XFXUXUXUXUXUXUXUXUXbXV.` w.wXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..             X J { ] ] ] ] ] ] ] ] ] ] ] [ I c _ ] ] ] ] ] ] ] ] ] ] ] _ 1               ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXwX2XF.S (.DXUXUXUXUXUXUXUXUXUXUXcX9.^ [.9XqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..                                                                                         ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXrX.X>.:.aXUXUXUXUXUXUXUXUXUXUXUXUX).o.u.6XwXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..                                                                                         ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXyXQ.Y (.BXUXUXUXUXUXUXUXUXUXUXUXUXpXf.( 3XwXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..                                                                                         ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXuXK.c 8XLXUXUXUXUXUXUXUXUXUXUXUXUXGXA.N 1XwXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..                                                                                         ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXiXF.a sXUXUXUXUXUXUXUXUXUXUXUXUXUXUXK.g <XwXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..                                                                                         ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXuXJ.k eXIXUXUXUXUXUXUXUXUXUXUXUXUXLXF.b 1XwXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXC..                                                                                         ) tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXyXR.H  XAXUXUXUXUXUXUXUXUXUXUXUXUXkXl.E 2XwXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXiXV.                                                                                          ^ tXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXtX{.@.t.hXUXUXUXUXUXUXUXUXUXUXUXUXoX-.6.5XwXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXuXU.j j j j j j j j j j j j j j j j j j j j j k u 7 h j j j j j j j j j j j j j j j j j j j a <.rXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXeX:Xb.K @XPXUXUXUXUXUXUXUXUXUXUXDXf.~ E.8XqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqX9X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X7XR.6.>X4X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X6XqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXwX@XU 8.5XIXUXUXUXUXUXUXUXUXGX).] -.9XqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXyX/.q.6XeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXwX6XE.J ;.3XUXUXUXUXUXUXUXFX).I $.XXwXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqX4XA.| ^ a.:XmXUXKXgX'.,.T 1.).0XqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXwX7XU.Q 0 ` ,.8.7.*.K 8 2..X0XwXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXwXdXi.  o       .   : oXuXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.I.tXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.q.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5Xq.^.tXqXqXqXqXqXqXqXqXqXqXpXy.              > |.tXqXqXqXqXqXqXqXqXqXqXqXtXI.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.#.U.yXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXyX/.q.7XeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeX7Xq./.yXwXwXwXwXwXwXwXwXwXwXaXu.              >  XuXwXwXwXwXwXwXwXwXwXwXwXyXU.#.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.%.r.b.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.b.u.,.x.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.x.,.u.b.v.v.v.v.v.v.v.v.v.v.N.)               $ q.m.v.v.v.v.v.v.v.v.v.v.v.b.r.%.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.$.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.#.%.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.%.#.@.@.@.@.@.@.@.@.@.@.@.$.Q l z z z z z l b | #.@.@.@.@.@.@.@.@.@.@.@.@.$.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.*.-.-.-.-.-.-.-.-.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&."
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.&.&.&.",
"&.&.&.&.%.O.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.O.%.@.O.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.O.@.%.O.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.O.%.&.&.&.",
"&.&.&.%.;.w.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.e.-.6.q.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.w.5.-.e.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.w.-.%.&.&.",
"&.&.*.o.i.vXuXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXuXmX0.$XlXpXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXpXxX.Xt.MXuXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXuXxXw.O.*.&.",
"&.&.*.O.t.pX5X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X5XdX8.|.tX8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X7XuX`.w.fX5X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X6XuX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqX9X7X6X5X6X7X9XqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqX6XeXjXvXnXvXjXrX6XqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XkX;Xj.=.+.*.g.&XlX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqX7XsXs.C &       $ B t.aX7XqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.w.tX2X5X5X5X5X1XpX4..     o O o       *.pX6XqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqX9X4X5X5X5X5X5X5X5X5X5X5X5X5X5X5X4XeX(.0.aX2X5X5X5X5X5X5X5X5X5X5X5X5X5X5X6XwXqXqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.O.z.SXlXvXvXvXkXFXg.    o .       . o     9.jX7XqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqX9XuXnXcXvXvXvXvXvXvXvXvXvXvXvXvXvXcXZX=Xh.JXlXvXvXvXvXvXvXvXvXvXvXvXvXvXbXlX9XwXqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.;.] 4 n z x x x l m =   X               X   f %XwX9XqXqXqX8XhX8..XiX0XqXqXqXqXqX9XgXY.w m x x x x x x x x x x x x x x v d 0 b z x x x x x x x x x x x x c s Q hX7XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.%.:.`                   .                 .   # 9.hX7XqXqXqX8XhX8..XiX0XqXqXqXqXqX8XzXm.                                                                      8 xX5XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.%.:.`   O X X X X X X .                     X   ~ vX5XqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXC.  $ X X X X X X X X X X X X X X X X . X X X X X X X X X X X X X X o   s zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.%.:.`   X                                   o   L nX5XqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @                                                               .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.%.:.`   o                                   X   W vX5XqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @                                                               .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.%.:.`                                     .   X 1.jX6XqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @       .                                                       .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.%.:.' . < : : : : ; , X   .               .   a {.rX9XqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @         & > : : : : : : : : : = % > : : : : : : : ; > X       .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.O.d.cXuXaXaXaXtXMX1.    .           .     +.kX6XqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     #   G.NXuXaXaXaXaXaXaXpXzXXXi.MXuXaXaXaXaXaXaXyXnX7   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.r.pX6X9X9X9X8X5XyX'     .             R rX8XqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   B.hX6X9X9X9X9X9X9X8XuX`.w.fX5X9X9X9X9X9X9X5XdX5   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqX8XyX;.O           X O.eX8XqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX3XZXf   .   .   8 NX4XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XhXi   .   .   5 aX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   5 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.O.t.iX5X8X8X8X8X8X8X2XjXp   .   .   5 sX4X8X8X8X8X8X8X8X5XsX8.|.rX7X8X8X8X8X8X5XgXN.  @     @   N.gX5X8X8X8X8X8X8X7XyX_.w.dX5X8X8X8X8X8X8X4XsX5   .   .   p jX2X8X8X8X8X8X8X8X5XuX0.+.*.&.",
"&.&.*.X.p.BXdXjXjXjXjXjXjXaXGXd   .   .   7 CXdXjXjXjXjXjXjXjXdXAX0.-XnXhXjXjXjXjXjXfXDXL.  #     #   L.DXfXjXjXjXjXjXjXhXMX+Xy.SXdXjXjXjXjXjXjXdXCX7   .   .   d GXaXjXjXjXjXjXjXjXfXMXe.O.*.&.",
"&.&.&.%.;.t.w.e.e.e.e.e.e.0.g.3   .       ; s.q.e.e.e.e.e.e.e.w.y.-.8.r.e.e.e.e.e.e.q.d.'   O     O   ' d.q.e.e.e.e.e.e.e.t.6.;.y.w.e.e.e.e.e.e.q.s.;       .   3 g.0.e.e.e.e.e.e.e.w.t.-.%.&.&.",
"&.&.*.+.8.XX`.].].].].].].(.&Xe   .   .   2 @X).].].].].].].]._.OX3.L.|.'.].].].].]._.$Xt.  +     +   t.$X_.].].].].].].'..XF.6.+X_.].].].].].].).@X2   .   .   e &X(.].].].].].].].`..X5.@.&.&.",
"&.&.*.o.i.cXyXaXaXaXaXaXaXrXVXs   .   .   6 nXyXaXaXaXaXaXaXaXyXnX9.$XkXpXaXaXaXaXaXuXNXF.  #     #   F.NXuXaXaXaXaXaXaXiXzX.Xt.MXyXaXaXaXaXaXaXyXnX6   .   .   s VXrXaXaXaXaXaXaXaXuXxXw.O.*.&.",
"&.&.*.o.y.aX7X0X0X0X0X0X0X5XlXp   .   .   5 fX6X0X0X0X0X0X0X0X7XgX8..XuX9X0X0X0X0X0X7XjXV.  @     @   V.jX7X0X0X0X0X0X0X9XiX'.e.hX7X0X0X0X0X0X0X6XfX5   .   .   p lX5X0X0X0X0X0X0X0X7XpX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @ . . @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XxXD.  X     X   D.zX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqX0XwXhXy.  a q q a   y.hXwX0XqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqX0XeXqX8.p r.pXUXUXiXw.i 9.qXeX0XqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXeXrX6.c jXUXPXLXLXPXUXhXz 7.tXeXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXiXU.f kXUXGXIXUXUXIXGXUXhXf Y.iXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXrX3XX.u.UXGXUXUXUXUXUXUXFXUXr.o.3XrXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXuX@XV dXIXIXUXUXUXUXUXUXIXIXpXV @XuXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqX0XpX|.t UXKXUXUXUXUXUXUXUXUXKXUXy |.pX0XqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqX0XpX}.e UXKXUXUXUXUXUXUXUXUXKXUXr }.pX0XqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXuX+Xm kXPXIXUXUXUXUXUXUXIXIXhXN +XuXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXrX1X{ k.UXFXUXUXUXUXUXUXFXUXg.| 2XrXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXuXG.j BXUXFXIXUXUXIXFXUXNXh G.uXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXrXwX=.A NXUXPXJXJXPXUXMXZ -.wXrXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqX0XrX6X&.c c.lXUXUXkXx.x *.6XrX0XqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqX0XeXdX1.  M v b m   1.dXeX0XqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX7XcXJ.            J.cX7XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  # . . #   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.sX7X0X0X0X0X0X0X5XzXp   .   .   5 gX6X0X0X0X0X0X0X0X7XgX8..XuX0X0X0X0X0X0X7XkXV.  @     @   V.kX7X0X0X0X0X0X0X9XpX'.e.hX7X0X0X0X0X0X0X6XgX5   .   .   p zX5X0X0X0X0X0X0X0X8XpX0.+.*.&.",
"&.&.*.o.u.zXtXiXiXiXiXiXiXwXNXa   .   .   6 vXrXiXiXiXiXiXiXiXtXbX9.#XhXuXiXiXiXiXiXtXmXD.  #     #   D.mXtXiXiXiXiXiXiXuXkX|.r.nXrXiXiXiXiXiXiXrXvX6   .   .   a NXwXiXiXiXiXiXiXiXtXlXq.O.*.&.",
"&.&.*.+.0.%X|..X.X.X.X.X.X{.,Xr   .   .   2 -X}..X.X.X.X.X.X.X|.=X4.T.#X.X.X.X.X.X.X|.>Xa.  +     +   a.>X|..X.X.X.X.X.X.X$XL.8.-X|..X.X.X.X.X.X}.-X2   .   .   r ,X{..X.X.X.X.X.X.X|.$X6.@.&.&.",
"&.&.&.%.-.0.8.8.8.8.8.8.8.5.i.3   .       - y.6.8.8.8.8.8.8.8.8.0.=.4.9.8.8.8.8.8.8.7.u.)   o     o   ) u.7.8.8.8.8.8.8.8.9.3.-.0.8.8.8.8.8.8.8.6.y.-       .   3 i.5.8.8.8.8.8.8.8.8.0.-.%.&.&.",
"&.&.*.o.p.NXsXhXhXhXhXhXhXpXDXd   .   .   7 VXsXhXhXhXhXhXhXhXsXCX0.=XbXgXhXhXhXhXhXdXAXK.  #     #   K.AXdXhXhXhXhXhXhXgXnXOXy.AXsXhXhXhXhXhXhXsXVX7   .   .   d DXpXhXhXhXhXhXhXhXdXmXe.O.*.&.",
"&.&.*.O.t.iX5X8X8X8X8X8X8X3XjXp   .   .   5 sX4X8X8X8X8X8X8X8X5XsX8.|.tX7X8X8X8X8X8X5XgXN.  @     @   N.gX5X8X8X8X8X8X8X7XyX_.w.dX5X8X8X8X8X8X8X4XsX5   .   .   p jX3X8X8X8X8X8X8X8X5XuX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX5   .   X   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XaX6   @ # @   p hX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX4XAX9           h GX2XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   6 hX7XqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqX8XkXV.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqX7XaX1.* *.P./.K.X.* r.dX7XqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   5 pX2X6X6X6X6X6X6X6X3XaX5.{.eX5X6X6X6X6X6X3XdXM.  @     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqX7XaX^ Q -XSXUXUXUXZX+XP  .fX6XqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .   .   7 SXgXlXlXlXlXlXlXlXhXSXi.>XMXkXlXlXlXlXlXhXGXP.  #     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqXqX7XlX:.! dXUXUXIXLXIXUXUXwXP q.zX6XqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .       O u t t t t t t t t t u < q y t t t t t t t i 5   .     @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqX9XrXOXx ;XUXPXIXUXUXUXPXLXUX[.n =XrX9XqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .                                                       .       @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqX7XzX<.4.DXUXIXUXUXUXUXUXPXUXNX&.w.zX7XqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .         . . . . . . . . . . . . . . . . . . . . . . .         @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqX5XNXD K.UXIXUXUXUXUXUXUXUXIXUXz.Q BX6XqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXp   .                                                               @   V.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqX5XZXj !.UXPXUXUXUXUXUXUXUXLXUXB.A ZX5XqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XzXa   X . . . . . . . . . . . . . . .   . . . . . . . . . . . . . . . #   C.kX8XqXqXqXqXqXqX0XaX].e.jX8XqXqX5XNXD K.UXIXUXUXUXUXUXUXUXIXUXz.W BX6XqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX5XxXw                                                                       N.lX8XqXqXqXqXqXqX0XaX].e.jX8XqXqX7XzX,.4.DXUXIXUXUXUXUXUXPXUXNX=.w.zX7XqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqX6XkXA < 0 9 9 9 9 9 9 9 9 9 9 9 9 9 9 q : 6 0 9 9 9 9 9 9 9 9 9 9 9 9 9 t # H.hX9XqXqXqXqXqXqX0XaX].e.jX8XqXqX9XtXoXx >XUXPXIXUXUXUXIXLXUX}.n &XrX9XqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqX0XfXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXfXZXu.:XnXhXjXjXjXjXjXjXjXjXjXjXjXjXjXlXyX0XqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqX6XzX=.^ gXUXUXIXLXIXUXUXtXU 6.xX6XqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqX7X6X7X7X7X7X7X7X7X7X7X7X7X7X7X7X4XaX6.}.eX6X7X7X7X7X7X7X7X7X7X7X7X7X7X6X0XqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqX7XaXQ ~ <XFXUXUXUXSX=XI [ dX7XqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqX7XpX>.* :.R.{.T.+.* 0.sX7XqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX4XAX0           h FX2XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XaX6   @ # @   p hX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX5   .   X   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.o.y.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX8..XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX].e.jX8XqXqXqXqXqXqX7XhX6   .   .   p zX6XqXqXqXqXqXqXqX8XaX0.+.*.&.",
"&.&.*.O.t.iX5X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X5XsX8.|.tX7X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X7XyX`.w.dX5X8X8X8X8X8X8X4XsX5   .   .   p jX3X8X8X8X8X8X8X8X5XuX0.+.*.&.",
"&.&.*.o.i.bXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXiXNX0.%XzXsXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXaXcXXXt.BXiXdXdXdXdXdXdXiXMX9   o X O   f ZXyXdXdXdXdXdXdXdXpXvXw.O.*.&.",
"&.&.&.%.:.i.t.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.t.p.-.0.u.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.i.8.;.p.t.y.y.y.y.y.y.e.g.@           : k.w.y.y.y.y.y.y.y.t.i.;.%.&.&.",
"&.&.&.&.%.o.O.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.O.o.%.+.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.+.%.X.O.o.o.o.o.o.o.o.O.' ` ` ` ` ` ] O.o.o.o.o.o.o.o.o.O.o.%.&.&.&.",
"&.&.&.&.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.*.*.*.*.*.*.*.*.*.*.;.:.:.:.:.:.;.*.*.*.*.*.*.*.*.*.*.*.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.%.%.%.%.%.%.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&."
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.=.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.&.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.&.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.=.&.&.&.&.",
"&.&.&.*.X.} | | | | | | | | | | | | | | | | | | | | | | | } $. .} | | | | | | | | | | | | | | | | | | | | | | }  .$.} | | | | | | | | | | | | | | | | | | | | | | | } X.*.&.&.&.",
"&.&.=.O.m.W.U.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.I.W.2.H.T.U.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.U.T.H.2.W.I.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.U.W.m.O.=.&.&.",
"&.&.-.} OXxXaXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXpXxXq.8XhXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXhX8Xq.xXpXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXaXxXOX} -.&.&.",
"&.&.-.| ].yX7X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X7XuX9.:XqX8X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X8XqX:X9.uX7X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X7XyX].| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqXqXqX8X6X6X6X7X9XqXqXqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqX0X7XiXlXvXcXjXeX7XqXqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX0XeXfX!.w.:.,.h.*XjX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqX0XrX1X` e       X l i.pX9XqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX,X9.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-. . XfXrXtXtXtXyX2Xb     X + O       1.iX9XqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXeXyXtXtXtXtXtXtXtXtXtXtXtXtXtXiX3Xw.gXeXtXtXtXtXtXtXtXtXtXtXtXtXyXwXqXqXqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.[ Q.6X:X>X>X-X9XI   X X .     . o     b.gX8XqXqXqX9XpX0.,XrXqXqXqXqXqXqXwX5X:X,X>X>X>X>X>X>X>X>X>X>X>X>X1X+X3.6X:X>X>X>X>X>X>X>X>X>X>X>X,X:X7XwXqXqXqXqXqXqX9XpX[.| -.&.&.",
"&.#.2.k                 .               o   J >XrX0XqXqX9XpX0.,XrXqXqXqXqXqX6XcX7.  X                                                         X   m.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.#.2.k   X                             . . O W.dX9XqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @                                                         @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.#.2.k   X                               +   H.hX8XqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @                                                         @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.#.2.k   X                               +   H.hX8XqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @                                                         @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.#.2.k                                 .   $ !.dX9XqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @                                                         @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.#.2.z   % # # # @ #   .               O   T 2XeX0XqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @       o # @ # # # # # # # @ O # # # # # # # # # X       @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| ].iX8X0X0X7XsX)   X           X   . A.gX8XqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` cX4X0X0X0X0X0X0XeX>X9.iX8X0X0X0X0X0X4XxXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| {.aXqXwXwXwXeX8XG   .       .     r.aX8XqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ' nX7XwXwXwXwXwXwXtX<X0.sX0XwXwXwXwXwX7XbXZ   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXeX0X{   X   .   % M.aX9XqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX8XdX@X  O   .   t NX5XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX0XaX^.  O   .   q aX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| '.yX7X8X8X8X8X7XiX/.  O   .   q sX5X8X8X8X8X8X8X6XyX9.:XqX8X8X8X8X8X3XlX7.  +   O   _ xX2X8X8X8X8X8X8XqX:X9.yX6X8X8X8X8X8X3XlXC   o   @   n.gX5X8X8X8X8X8X7XyX'.| -.&.&.",
"&.&.-.} @XbXdXgXgXgXgXdXmXXX  O   .   r BXsXgXgXgXgXgXgXdXbXw.qXkXgXgXgXgXgXpXFXt.  @   +   | HXiXgXgXgXgXgXgXkXqXw.bXdXgXgXgXgXgXiXGXD   o   @   F.ZXsXgXgXgXgXgXdXbX@X} -.&.&.",
"&.&.*.#.q.s.i.p.p.p.p.i.h.;.  X   .   < k.u.p.p.p.p.p.p.i.s.;.y.p.p.p.p.p.p.y.c.U   o   o   n v.t.p.p.p.p.p.p.p.y.;.s.i.p.p.p.p.p.y.c.u   X   o   [ l.u.p.p.p.p.p.i.s.q.#.*.&.&.",
"&.&.=.X.P.#X X.X.X.X.X X&XS.  o   .   8 -X|..X.X.X.X.X.X X#X5._.oX.X.X.X.X.X{.<X*.  +   O   R 2X[..X.X.X.X.X.XoX_.5.#X X.X.X.X.X.X{.1Xb   X   +   u.:X}..X.X.X.X.X X#XP.X.=.&.&.",
"&.&.-.} .XjXyXiXiXiXiXyXlX{.  O   .   e cXtXiXiXiXiXiXiXyXkXq.5XsXiXiXiXiXiXeXBXw.  @   O   [ CXwXiXiXiXiXiXiXsX5Xq.kXyXiXiXiXiXiXwXVXA   o   @   Z.nXtXiXiXiXiXiXyXjX.X} -.&.&.",
"&.&.-.| [.iX9X0X0X0X0X9XaX).  O   .   w fX7X0X0X0X0X0X0X8XiX0.>XeX0X0X0X0X0X6XxX8.  @   O   ` vX5X0X0X0X0X0X0XeX>X0.iX8X0X0X0X0X0X5XxXC   o   @   m.jX7X0X0X0X0X0X9XiX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XxX8.  @ . +   ' vX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX7XMX6.  #   +   ) BX6XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXiXc.i 5.4XhX9Xs.u e.tXqX0XqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXpXh.M uXUXUXUXUXUXbXL 2.iXwXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXtX}.x sXUXLXUXIXUXLXUXBXC K.aX0XqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqX0XyX;.p.UXKXUXUXUXUXUXHXUXZ. .8XeXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqX0XtXZ eXUXUXUXUXUXUXUXIXUXvXS ;XtXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqX0XtXi AXUXUXUXUXUXUXUXUXLXUXh %XyXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqX0XtXl cXUXUXUXUXUXUXUXUXPXLXb *XtXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqX0XtX) ~.UXLXUXUXUXUXUXKXUX#X! 3XrXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXyXA.J UXUXJXIXUXUXJXKXUX` u.uXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXeXeX) 1.UXUXLXHXKXUXUXg.P 2XyX0XqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqX0XrX<XE | *XIXUXUX4X=.H oXuX9XqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqX9XeXiXU = W E W 5 z 0XtX8XqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX4XmXp.          X.VX3XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XxX7.  $ o #   ` cX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX).  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX5XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| {.aX0XwXwXwXwX0XdX_.  O   .   w hX9XwXwXwXwXwXwX0XaX0.<XtXwXwXwXwXwX7XvX9.  @   O   ' nX6XwXwXwXwXwXwXtX<X0.aX0XwXwXwXwXwX6XvXZ   o   @   M.lX9XwXwXwXwXwX0XaX{.| -.&.&.",
"&.&.&.%.2.8.7.7.7.7.7.6.w.O.  X   .   > r.5.7.7.7.7.7.7.7.8.=.5.7.7.7.7.7.7.4.i.H   o   X   z p.4.7.7.7.7.7.7.7.5.=.8.7.7.7.7.7.7.4.i.r   .   o   ^ y.5.7.7.7.7.7.7.8.2.%.&.&.&.",
"&.&.-.| [.iX9X0X0X0X0X9XaX).  O   .   w fX7X0X0X0X0X0X0X8XiX0.>XeX0X0X0X0X0X6XxX8.  @   O   ` vX5X0X0X0X0X0X0XeX>X0.iX8X0X0X0X0X0X5XxXC   o   @   m.jX7X0X0X0X0X0X9XiX[.| -.&.&.",
"&.&.-.| [.pX0XqXqXqXqX0XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ' bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XvXC   o   @   M.kX8XqXqXqXqXqX0XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   O . @   m.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX4XMXD           S.lX7XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   w gX8XqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqX6XcX8.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXqX9XrXyXa - g p j   7.zX0X0XqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   q iX3X5X5X5X5X5X5X3XeX7.=X8X5X5X5X5X5X1XhX5.  +   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqX8XuX#XU ) &XPXUXmXS.B 3.tXqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O   .   t HXxXbXbXbXbXbXbXcXAXd.aXMXbXbXbXbXbXlXUXa.  @   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqX0XuX<XP a.UXUXPXLXIXUXVXL 0.aX0XqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O       - O.{ } } } } } } { X.b ` | } } } } } [ @.v   X   O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqXqXqXaX5.O.UXKXKXUXUXIXHXUXvXz |.rX0XqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O     .                                             X     O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqX0XuX%X~ >XUXJXUXUXUXUXUXLXUXg.=.dX8XqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O       . + O O O O O O O O + o O + O O O O O O + X       O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqX0XsX(.K UXLXUXUXUXUXUXUXUXUX1XV kX7XqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XsX_.  O                                                         O   ` bX5XqXqXqXqXqXqXrX,X0.pX9XqX0XdXW.Z UXJXUXUXUXUXUXUXIXUXiXd lX7XqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX0XsX_.  % + + + + + + + + + + + + + @ o + @ + + + + + + + + + + + &   { vX5XqXqXqXqXqXqXrX,X0.pX9XqX0XsX).L UXLXIXUXUXUXUXUXUXUX:XS jX7XqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX9XdX^.                                                                T mX5XqXqXqXqXqXqXrX,X0.pX9XqX0XyX=X^ @XUXJXUXUXUXUXUXLXUXe.2.sX9XqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqX0XyX=X;.5.4.4.4.4.4.4.4.4.4.4.4.4.2.8.G :.5.3.4.4.4.4.4.4.4.4.4.4.6.-.S.sX8XqXqXqXqXqXqXrX,X0.pX9XqXqX0XsXe.' UXIXKXUXUXUXJXUXaXk @XeX0XqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqX0XtXbXcXcXcXcXcXcXcXcXcXcXcXcXcXzXCXs.iXmXcXcXcXcXcXcXcXcXcXcXcXcXbXfX9XwXqXqXqXqXqXqXrX,X0.pX9XqXqX0XtX7XQ <.UXUXUXUXUXUXhXB g.aX0XqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqXqX0X6X6X6X6X6X6X6X6X6X6X6X6X6X6X4XrX7.-X9X6X6X6X6X6X6X6X6X6X6X6X6X6X8XwXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqX9XtX,X_ D (.BXPXsXa.l s.uX0XqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqXqX9XqXkXk . 6 , 9   p.cX9XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX5XnXA       X   V.kX7XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpX0.,XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX,X0.pX9XqXqXqXqXqX6XcXC   o   @   M.kX8XqXqXqXqXqX9XpX[.| -.&.&.",
"&.&.-.| [.iX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X8XpX0.,XeX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XeX,X0.pX8X0X0X0X0X0X5XcXC   o   @   m.jX7X0X0X0X0X0X9XiX[.| -.&.&.",
"&.&.-.|  XgXrXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXrXgX0.3XpXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXpX3X0.gXrXyXyXyXyXyX0XMXS   O . #   C.vXeXyXyXyXyXyXrXgX X| -.&.&.",
"&.&.=...W.<X&X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X&X<X7.XX;X*X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X*X;XXX7.<X&X=X=X=X=X=X@XeXx           d.9X$X=X=X=X=X=X&X<XW...=.&.&.",
"&.&.&.*.+.X.o.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.o.X.%.o.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.o.%.X.o.X.X.X.X.X...%.x 8 e w r 6 R #...X.X.X.X.X.o.X.+.*.&.&.&.",
"&.&.&.&.*.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.&.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.&.=.=.=.=.=.=.=.=.*.<.3.2.2.2.3.;.*.=.=.=.=.=.=.=.=.*.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.$.#.#.#.#.#.%.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&."
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.*.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.*.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.*.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.*.&.&.&.&.",
"&.&.&.&.o...X.X.X.X.X.X.X.X.X.X.X.X.X.X.X...#.X...X.X.X.X.X.X.X.X.X.X.X.X.X.X...X.#...X.X.X.X.X.X.X.X.X.X.X.X.X.X.X...o.&.&.&.&.",
"&.&.*.$.g.m.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.m.9.x.n.b.b.b.b.b.b.b.b.b.b.b.b.b.b.n.x.9.m.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.m.g.$.*.&.&.",
"&.&.=.o.*XkXpXaXaXaXaXaXaXaXaXaXaXaXaXaXpXkXA.0XfXaXaXaXaXaXaXaXaXaXaXaXaXaXaXfX0XA.kXpXaXaXaXaXaXaXaXaXaXaXaXaXaXpXkX*Xo.=.&.&.",
"&.&.*.O.oXtX8X9X9X9X9X8X7X7X8X9X9X9X9X9X7XtXN.<XqX9X9X9X9X9X9X9X9X9X9X9X9X9X9XqX<XN.tX7X9X9X9X9X9X9X9X9X9X9X9X9X9X8XtXoXO.*.&.&.",
"&.&.*.O.OXuX0XqXqXqX8XrXpXpXrX8XqXqXqXqX9XuXB.2XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XB.uX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqXqX0XfX<X{.{.2XfX0XqXqXqX9XuXB.2XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XB.uX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XuXOXO.*.&.&.",
"&.&.*.o..XrX7X7X8XuXi.u     a g.iX0XqXqX9XuXB.2XeXqXqXqXqX0X8X8X8X8X8X8X8X8X8X0X,XM.rX6X8X8X8X8X8X8X8X8X9XqXqXqXqX0XuXOXO.*.&.&.",
"&.&.*.@.,XcXgXgXcX,.    . .     6.dX9XqX9XuXB.2XeXqXqXqX0XuXjXhXhXhXhXhXhXhXhXlXtXJ.vXgXhXhXhXhXhXhXhXjXiX0XqXqXqX0XuXOXO.*.&.&.",
"&.%.>.Y g C M N M     X     o   * }.yX0X9XuXB.2XeXqXqX8XgXB.f C N N N N N N N B n a V N N N N N N N C g p.hX8XqXqX0XuXOXO.*.&.&.",
"&.$.<.D             .         o   8.kX7X9XuXB.2XeXqXqX7XzXq.                                            ..xX7XqXqX0XuXOXO.*.&.&.",
"&.$.<.H   % # # # .           O   -.zX7X9XuXB.2XeXqXqX7XlXu.  # o O # # # # # # # + # # # # # # O o #   &.zX7XqXqX0XuXOXO.*.&.&.",
"&.$.<.D             X         o   a.hX8X9XuXB.2XeXqXqX7XlXy.  O .                                 . O   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.%.;.^  .3.>.,.,.-   .     X   7 :XeX0X9XuXB.2XeXqXqX7XlXy.  +   3 4.>.,.,.,.<.=.W 2.>.,.,.:.7.r   @   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.@.3XmXlXlXMXB.o   . .   @ S.aX9XqX9XuXB.2XeXqXqX7XlXy.  @   j VXkXzXzXzXvXpXP.MXkXzXzXhXGXL   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.=.o. XeX6X7X5XhXS.  X .   L.hX8XqXqX9XuXB.2XeXqXqX7XlXy.  @   d yX5X7X7X7X9X>Xm.eX5X7X7X3XdXS   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XuX+X  .     *XyX0XqXqX9XuXB.2XeXqXqX7XlXy.  @   d sX9XqXqXqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX{.  .     oXuX0XqXqX9XuXB.2XeXqXqX7XlXy.  @   d sX9XqXqXqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.oXtX8X0X8XuX}.  .     OXyX8X0X0X8XyXB.<XwX9X0X6XjXt.  @   d pX8X0X0X9XwX<XB.yX8X0X0X6XhXD   #   #.lX5X0X0X8XtXoXO.*.&.&.",
"&.&.=.o.*XjXiXaXiXlX@X  .     -XjXiXaXaXiXjXA.0XdXpXaXyXNXs.  #   g xXuXaXaXpXdX0XA.jXiXaXaXyXMXH   $   =.VXtXaXaXiXjX*Xo.=.&.&.",
"&.&.*.@.K.].)._.(.}.Z.  .     G.{.(._._.).[.f.Q.`.)._.^.@X=.  +   t |.(._._.).`.Q.f.[.)._._./.+Xn   @   ( #X^._._.).].K.@.*.&.&.",
"&.&.*.@.D.^.W.Q.W.).m.  .     C.(.W.Q.Q.W./.a.U.!.Q.Q.R.}.$.  +   r _.E.Q.Q.Q.!.U.a./.W.Q.Q.R.{.v   @   ~ |.T.Q.Q.W.^.D.@.*.&.&.",
"&.&.=.o.=XkXpXaXpXzX#X  .     ;XkXpXaXaXpXkXA.0XfXaXaXyXBXs.  #   g xXiXaXaXaXfX0XA.kXpXaXaXuXNXH   $   -.CXyXaXaXpXkX=Xo.=.&.&.",
"&.&.*.O.oXtX8X9X8XuX{.  .     OXtX8X9X9X8XtXN.<XwX9X9X5XjXt.  @   d pX7X9X9X9XwX<XN.tX8X9X9X6XhXD   #   #.kX5X9X9X8XtXoXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXqXqX7XjXu.  $   g pX8XqXqXqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXqXqX6XMXw.      e lX0XqXqXqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXqX9XaXW.Q F.9XOX .9.yXqXqXqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeX9XiX}.} nXUXUXUXUXf.y.fX9XqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeX0XpX1.&XUXGXPXLXUXUX&.#XyX0XeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXwX7X#.JXUXUXUXUXKXUXn.A.hX9XeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXwX6X@.IXIXUXUXUXKXUXN.V.jX9XeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeX0XuX;.9XUXHXUXPXPXUX1.{.iX9XeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeX9XsXR.%.UXUXUXUXUXI.,.sX9XqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXqX9XsXv.X.=XAXfXa.@.7XeX0XqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXqXqX6XmX<.  6 @ 9 aXeX0XqXqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXqXqX7XkXa.  X   h sX8XqXqXqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXqXqX7XlXt.  #   d aX9XqXqXqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.oXtX8X9X7XuX{.  .     oXtX8X9X9X7XtXN.<XqX9X9X5XjXt.  @   d iX7X9X9X9XqX<XN.tX7X9X9X5XhXD   #   #.kX5X9X9X8XtXoXO.*.&.&.",
"&.&.=.o.*XjXpXaXiXlX#X  .     -XkXpXaXaXiXkXA.0XfXaXaXyXBXs.  #   g xXiXaXaXaXfX0XA.kXiXaXaXyXMXH   $   =.VXyXaXaXpXjX*Xo.=.&.&.",
"&.&.*.#.v.G.S.S.A.K.d.  .     j.J.S.S.S.S.G.e.V.F.S.S.Z.R.|   +   q L.A.S.S.S.F.V.e.G.S.S.S.Z.T.k   +   Y E.C.S.S.S.G.v.#.*.&.&.",
"&.&.*.+.(.:X%X&X%X,XE.  .     /.>X%X&X&X%X>Xx.oX=X&X&X#X8X5.  @   p 1X%X&X&X&X=XoXx.>X%X&X&X#X7XV   #   | 9X#X&X&X%X:X(.+.*.&.&.",
"&.&.*.o.$XdXrXyXrXgXoX  .     %XdXrXyXyXrXdXC.6XiXtXyXwXbXi.  @   f hXrXyXyXtXiX6XC.dXrXyXyXwXvXG   #   &.nXqXyXyXrXdX$Xo.*.&.&.",
"&.&.*.O.OXyX9X0X9XiX}.  .     +XuX9X0X0X9XuXB.1XeX0X0X7XkXt.  @   d aX8X0X0X0XeX1XB.uX9X0X0X7XjXD   %   #.lX6X0X0X9XyXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     +XuX0XqXqX9XuXB.2XeXqXqX7XlXy.  @   d sX9XqXqXqXeX2XB.uX9XqXqX6XlXK       -.zX6XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     XXrX7X8X8X6XrXM.,X0X8X8X4XhXr.  @   d sX9XqXqXqXeX2XB.uX9XqX0XwXdXk : g @ ! cX8XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     ,XvXfXhXhXfXvXJ.tXkXhXhXsXSXg.  #   d sX9XqXqXqXeX2XB.uX0X0XeX8X@.l.bXUXdX8.5.uXqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .     f.F.V.C.C.V.F.-.n.A.C.C.B.I.{   +   d sX9XqXqXqXeX2XB.uX9X9XfX5.J.UXUXIXUXUXy.x.fX9X0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  .                                   . X   d sX9XqXqXqXeX2XB.uX9XuX#X>.UXIXPXUXKXUXbX%.7XeX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX|.  X . . O + + + + + + o O + + + + + o . o   f aX9XqXqXqXeX2XB.uX8XdXE.i.UXKXUXUXUXLXUX;.&XyX9XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX9XpX}.                                            i sX9XqXqXqXeX2XB.uX8XsX^.t.UXKXUXUXUXPXUX;.-XtX9XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqX0XiXXX> 4 3 3 3 3 3 3 3 3 4 : 2 3 3 3 3 3 3 3 5 = V aX9XqXqXqXeX2XB.uX9XeX5X+.bXUXJXLXHXUX2X=.uXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqXqXqXqX0X0X0X0X0X0X0X0X0X9XyXB.1XeX0X0X0X0X0X0X0X0X0XqXqXqXqXqXeX2XB.uX0X9XfXA.-.PXUXUXUXbX} `.aX9X0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqXqXqXqXwXwXwXwXwXwXwXwXwX0XiXV.2XrXqXwXwXwXwXwXwXwXqXqXqXqXqXqXeX2XB.uX9XqX9XaXN.U H.#Xc.P Q.aX9XqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqXqXqXqXqXqXqXqXqXqXqXqXqX9XuXB.1XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XB.uX9XqXqX6XMXZ       #.BX5XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqXqXqXqXqXqXqXqXqXqXqXqXqX9XuXB.2XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XB.uX9XqXqX7XhXG   &   $.lX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXuX0XqXqXqXqXqXqXqXqXqXqXqXqXqX9XuXB.2XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XB.uX9XqXqX7XkXF   #   $.zX7XqXqX0XuXOXO.*.&.&.",
"&.&.*.O.OXyX9X0X0X0X0X0X0X0X0X0X0X0X0X0X9XyXB.1XwX0X0X0X0X0X0X0X0X0X0X0X0X0X0XwX1XB.yX9X0X0X7XjXF   $   $.lX6X0X0X9XyXOXO.*.&.&.",
"&.&.*.o.$XsXrXtXtXtXtXtXtXtXtXtXtXtXtXtXrXdXC.6XiXtXtXtXtXtXtXtXtXtXtXtXtXtXtXiX6XC.dXrXtXtXqXvXA   X   #.nXqXtXtXrXsX$Xo.*.&.&.",
"&.&.&.%.7.w.q.q.q.q.q.q.q.q.q.q.q.q.q.q.q.w.<.0.w.q.q.q.q.q.q.q.q.q.q.q.q.q.q.w.0.<.w.q.q.q.0.i.n > 8 ; P a.9.q.q.q.w.7.%.&.&.&.",
"&.&.&.&.@.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.$.@.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.@.$.+.+.+.+.+.O.-.>.:.,.*.O.+.+.+.+.+.@.&.&.&.&.",
"&.&.&.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.*.*.*.*.*.*.%.%.%.%.&.*.*.*.*.*.*.*.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&."
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.*.*.*.*.*.*.*.*.*.*.*.*.*.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.&.&.&.",
"&.&.&.&.$.@.@.@.@.@.@.@.@.@.@.@.@.$.@.@.@.@.@.@.@.@.@.@.@.@.#.#.@.@.@.@.@.@.@.@.@.@.@.@.&.&.&.&.",
"&.&.&.%.2.8.6.7.7.7.7.7.7.7.7.7.7.<.7.7.7.7.7.7.7.7.7.7.6.8.2.3.7.7.7.7.7.7.7.7.7.7.7.7.=.&.&.&.",
"&.&.=.X.`.iX9XqXqX0X0X0XqXqXqXqXwXT.qXqXqXqXqXqXqXqXqXqX0XiX].+XuX0XqXqXqXqXqXqXqXqXqXqX7.@.*.&.",
"&.&.=.X.`.iX0XqX9XeXiXrX9XqXqXqXwXT.qXqXqXqXqXqXqXqXqXqX0XiX].+XuX0XqXqXqXqXqXqXqXqXqXqX7.@.*.&.",
"&.&.=.X.(.tX6X7XsX7XoX1XdX0XqXqXqXT.0XqXqXqX9X7X8X8X8X8X6XrX_.XXeX7X8X8X8X7X8XqXqXqXqXqX7.@.*.&.",
"&.&.=.o.+XbXfXxXN.t o 4 w.uX0XqXwXT.0XqXqX0XpXkXhXjXjXjXgXbX#X<XvXhXjXjXjXjXgXqXqXqXqXqX7.@.*.&.",
"&.&.=. .5.v.v.w..   .     l.dX8XwXT.0XqX0XuX).f.x.z.z.z.l.b.6.e.v.l.z.z.z.k.N.0XqXqXqXqX7.@.*.&.",
"&.%.-.[           X   O   v iX9XqXT.0XqX7XzXO.                              & 8XwX0XqXqX7.@.*.&.",
"&.%.-.[         X     X   d yX0XqXT.0XqX7XlX-.  $                       +   9 8XwX0XqXqX7.@.*.&.",
"&.&.-.} V I U N       o   &.fX8XqXT.0XqX7XlX=.    t R K L U C S I L U A .   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.o.+XbXgXfX]   o   C 4XrX0XwXT.0XqX7XlX=.    1.DXsXgXbX#X<XcXfXbX-X.   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.X.).tX5XwXrX4     +XsX8XqXwXT.0XqX7XlX=.    &.hX4X6XtX_.XXeX5XtX}..   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.o.`.uX8X0X6X7   X |.yX9X0XqXY.0X0X6XkX*.    *.kX6X9XuX'.OXyX8XuX X.   6 8XqX9X0X0X7.@.*.&.",
"&.&.=.X.{.gXrXiXrX7   . +XgXtXuXuXW.yXuXeXnX;.    ;.nXeXtXgX|.%XfXrXgX@X.   7 rXiXyXuXuX7.@.*.&.",
"&.&.*.O.P.*XoX@XoX3   . Y.*XOX+X+XZ.+X+XXX2X .     .2XXXOX*XI.!.%XoX*XY..   3 oX@XOX+X+X3.#.*.&.",
"&.&.*.+.D. X`.[.`.2   . F..X`.].].m.'.].).%X]     ] %X).'. XF.I.|.`..XF..   2 `.[.'.].].2.#.*.&.",
"&.&.=.X.}.jXyXpXtX7   . #XhXyXiXpXQ.uXiXrXmX:.    :.mXrXuXhX X*XgXtXhX#X.   7 tXpXuXiXiX8.@.*.&.",
"&.&.=.o._.uX8XqX7X6   .  XuX8X9X0XY.9X0X5XlX:.    :.lX5X8XuX'.OXtX7XuX X.   6 7XqX9X0X0X6.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . .XiX9XqXwXT.0XqX0XdX` l l ` fX0X9XiX].+XuX9XiX.X.   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . .XiX9XqXwXT.0X0XuXd.[.UXUX].f.iX9XiX].+XuX9XiX.X.   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . .XiX9XqXwXT.9XpX_.F.UXLXLXUXD._.iXuX].+XuX9XiX.X.   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . .XiX9XqXwXT.8XgXS.-XUXLXLXUX-XS.fXyX].+XuX9XiX.X.   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . .XiX9XqXwXT.9XsX!.Y.UXHXHXUXU.~.pXuX].+XuX9XiX.X.   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . .XiX9XqXwXT.0XqXrXy.,XUXUX,Xt.rX9XiX].+XuX9XiX.X.   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . .XiX9XqXwXT.0X0XwXrX' ! ! ' rXwX9XiX].+XuX9XiX.X.   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . .XiX9XqXwXT.0XqX6XcX:.    :.cX6X0XiX].+XuX9XiX.X.   6 8XwX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX9X6   . .XiX0XqXwXT.qXqX7XkX*.    *.kX7X0XiX].+XuX9XiX.X.   6 9XwXqXqXqX7.@.*.&.",
"&.&.=.o.`.iX8XqX8X6   .  XuX9X0XqXT.0XqX7XkX*.    *.kX7X9XuX'.+XyX8XuX X.   6 8XqX0XqXqX7.@.*.&.",
"&.&.*.@.m.Q.Y.R.U.1   . b.!.Y.T.T.l.T.T.I.'.^     ^ '.I.Y.Q.m.Z.W.U.!.b..   1 U.R.Y.T.T.<.$.&.&.",
"&.&.=.X.'.pX9XeX9X6   . .XpX0XqXwXT.qXwX8XzX=.    =.zX8X0XpX].+XuX9XpX.X.   6 9XeXqXwXwX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . .XiX9XqXqXT.0XqX7XlX*.    *.lX7X9XiX].+XyX9XuX.Xo   9 8XqX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . {.rX6X7X8XI.7X7X3XgX&.    =.lX7X0XiX].+XuX8XdX.X    - wXeX0XqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . >XMXjXlXzX'.kXlXgXGX2.    =.lX7X0XiX].+XyXeX4X9.Y.wXM.s.rXqXqXqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X6   . ` %.+.@.@.W +.@.O.-.z     =.lX7X0XiX].+XtXiXg.2XUXUXUX/.A.sX9XqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X9   +                       %   ;.lX7X0XiX].+XpX,Xz.UXJXLXUXFXd.tX0XqX7.@.*.&.",
"&.&.=.X.`.iX9XwX8X%                               o.zX7X0XiX].+XpX<Xl.UXKXLXUXDXd.tX0XqX7.@.*.&.",
"&.&.=.X.`.iX9XqX0Xq.:.<.,.,.,.,.<.` ,.<.,.,.,.1.%.L.pX9X0XiX].+XtXpXj.-XUXUXUXE.F.sX9XqX7.@.*.&.",
"&.&.=.X.`.iX9XqXqXjXlXlXlXlXlXlXlX'.kXlXlXlXlXlXzXaX0XqX0XiX].+XyXwX7X0.C.<Xf.h.yXqXqXqX7.@.*.&.",
"&.&.=.X.`.iX9XqXqX8X7X7X7X7X7X7X8XI.7X7X7X7X7X7X7X9XqXqX0XiX].+XuX8XsXOX    = rXeX0XqXqX7.@.*.&.",
"&.&.=.o._.uX8X9X9X9X9X9X9X9X9X9X0XY.9X0X9X9X9X9X9X9X9X9X8XyX'.OXtX7XyX|.O   9 6X0X9X0X9X6.@.*.&.",
"&.&.=.X.}.jXuXiXiXiXiXiXiXiXiXiXpXQ.iXiXiXiXiXiXiXiXiXiXuXjX X*XgXyXhX#X.   7 yXpXiXiXiX8.@.*.&.",
"&.&.*.+.S.}._.`.`.`.`.`.`.`.`.`.'.m.`.`.`.`.`.`.`.`.`.`._.}.D.P.{.).|.D..   2 ).'.`.`.`.2.$.*.&.",
"&.&.&.*.+.X.o.X.X.X.X.X.X.X.X.X.X.@.o.X.X.X.X.X.X.X.X.X.o.X.+.O.X.X.o.X.{ [ { X.o.X.X.X.%.&.&.&.",
"&.&.&.&.*.=.=.=.=.=.=.=.=.=.=.=.=.*.=.=.=.=.=.=.=.=.=.=.=.=.*.*.=.=.=.=.-.-.-.=.=.=.=.=.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.%.%.%.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&."
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.&.&.&.",
"&.&.&.&.#.@.@.@.@.@.@.@.@.@.@.#.$.@.@.@.@.@.@.@.@.@.@.#.$.@.@.@.@.@.@.@.@.@.@.@.&.&.&.&.",
"&.&.&.%.3.8.7.7.7.7.7.7.7.7.7.4.2.8.7.7.7.7.7.7.7.7.7.5.2.7.7.7.7.7.7.7.7.7.7.7.=.&.&.&.",
"&.&.*.O.{.uX9XqX0X7X8X0XqX0XtX=X'.uX9XqXqXqXqXqXqX0XrX>X).uX9XqXqXqXqXqXqXqXqX0X7.@.*.&.",
"&.&.*.O.}.iX0X9XtXjXhXeX0XqXtX=X'.iX0XqXqXqXqXqXqXqXrX>X).uX0XqXqXqXqXqXqXqXwXqX7.@.*.&.",
"&.&.*.O.[.yX7XaX-Xk.v.3XuX9XtX=X'.uX9XqX0X0X0X0X0X9XeX:X(.yX8X0X0X0X0X0XqXqXqXqX7.@.*.&.",
"&.&.*.O.XXdXfX!.1     u @XyXrX=X'.uX0XqXeXuXuXuXuXyXaX4X[.fXtXuXuXuXuXeXqXqXqXqX7.@.*.&.",
"&.%.-.} i g k =   O +   Q sXeX=X'.uX7XfXZ.0 h f g g g s y h f g f h 9 l.gX8XqXqX7.@.*.&.",
"&.%.-.[         O   X   y eXtX=X'.uX6XjXf.                            7.lX7XqXqX7.@.*.&.",
"&.%.-.{ 7 q r @   . o   I sXeX=X'.uX6XjXk.  O 1 e 0 q 9 6 w 0 w 3 O   w.kX7XqXqX7.@.*.&.",
"&.&.*.O.[.rXyXJ.&     5 }.uXeX=X'.uX6XjXj.    h.gX6XeX:X(.yX5XdXC.    q.kX7XqXqX7.@.*.&.",
"&.&.*.O.}.pX6XbX7.    B.zX7XtX=X'.uX6XjXj.    k.kX8XtX,X_.iX8XhXZ.    q.kX7XqXqX7.@.*.&.",
"&.&.*.O.[.yX4XgXq.    Z.sX6XrX*X`.yX5XgXh.    h.gX6XwX:X(.tX5XdXC.    0.jX6X0X9X7.@.*.&.",
"&.&.=.o.XXgXwXbXr.    D.xXeXsX,X}.gXwXvXx.    x.vXeXaX3X].fXeXxXF.    r.nXeXuXuX7.@.*.&.",
"&.&.*.@.D.[.~.OX#.    r.XX^.'.Y.A.].^.oX2.    2.oX^.`.E.C.].^.XXr.    #.OX^.).).2.$.*.&.",
"&.&.*.O.^.4X*XeX4.    v.0X-X2X.XQ.4X=XwXi.    i.wX-X1X+XE.3X=X0Xv.    4.eX-X>X>X5.#.*.&.",
"&.&.*.o. XsX9XcXe.    S.kXqXiX:X[.sX0XlXx.    x.lXqXuX1X`.aX0XkXS.    e.cX0XrXrX7.@.*.&.",
"&.&.*.O.{.uX6XkXq.    Z.gX7XtX=X'.uX5XcXu.    i.cX6XrX>X).uX6XgXZ.    q.kX7XqX0X7.@.*.&.",
"&.&.*.O.{.iX6XkXq.    Z.gX8XtX=X'.yXuX{.d.qXqXd.{.iXeX>X).uX7XgXZ.    q.kX7XqXqX7.@.*.&.",
"&.&.*.O.{.iX6XkXq.    Z.gX8XtX=X'.iX7Xj.JXUXUXJXh.9XtX>X).uX7XgXZ.    q.kX7XqXqX7.@.*.&.",
"&.&.*.O.{.iX6XkXq.    Z.gX8XtX=X'.fXOXU.UXGXGXUXI.+XaX>X).uX7XgXZ.    q.kX7XqXqX7.@.*.&.",
"&.&.*.O.{.iX6XkXq.    Z.gX8XtX=X'.aX1Xc.UXUXUXUXc.2XyX>X).uX7XgXZ.    q.kX7XqXqX7.@.*.&.",
"&.&.*.O.{.iX6XkXq.    Z.gX8XtX=X'.yXiXI.G.LXLXF.I.pXwX>X).uX7XgXZ.    q.kX7XqXqX7.@.*.&.",
"&.&.*.O.{.iX6XkXq.    Z.gX8XtX=X'.uX6XlX9.4 4 9.zX7XrX>X).uX7XgXZ.    q.kX7XqXqX7.@.*.&.",
"&.&.*.O.{.yX5XjX0.    C.fX6XrX*X`.yX5XgXz.    z.gX6XeX:X(.yX5XfXC.    0.jX6X0X9X7.@.*.&.",
"&.&.=.o.XXgXwXnXt.    F.cXrXdX,X|.gXeXvXx.    x.vXrXsX4X].gXeXcXF.    t.nXeXiXuX8.@.*.&.",
"&.&.*.@.H.|.(.$X%.    y.+X).{.E.D.|.).#X4.    4.#X).[.Q.A.}.).+Xy.    %.$X).'.'.2.$.*.&.",
"&.&.*.+.Q.<X#X9X1.    z.6X%X>X}.E.,X$X8Xt.    t.8X%X:X.XY.,X$X6Xz.    1.9X%X=X=X4.#.*.&.",
"&.&.*.o. XdX0XvXe.    D.lXwXpX>X{.dX0XxXz.    z.xXqXiX2X'.sXqXkXF.    t.xXqXtXtX7.@.*.&.",
"&.&.*.O.{.uX5XjXq.    B.aX4XqX%X).rX3XdXg.    j.hX7XrX>X).uX5XlXM.    4.vX5XqX0X7.@.*.&.",
"&.&.*.O.{.iX6XkXq.    P.VXsXzX7X@XvXaXZXm.    j.jX7XrX>X).yXtX%Xt.%X<Xu.{.iX0XqX7.@.*.&.",
"&.&.*.O.{.iX6XkXq.    c Y K I F V I K T j     j.jX7XrX>X).yXeXj.bXUXUXLXh.6XeX0X7.@.*.&.",
"&.&.*.O.{.iX6XkX0.  X                     X   h.jX7XrX>X).sX=XF.UXGXGXUX!.}.pX0X7.@.*.&.",
"&.&.*.O.{.iX6XkXr.  * % & & & % % * & & % &   z.hX7XrX>X).iX5Xx.UXUXIXUXB.=XtX0X7.@.*.&.",
"&.&.*.O.{.iX9XwX3X%X*X&X&X&X;X].U.>X%X&X&X*X%X4XwX0XrX>X).tXpXU.H.UXUX/.C.pX0XqX7.@.*.&.",
"&.&.*.O.{.iX0XqXeXyXyXyXyXtXaX,X}.dXrXyXyXyXyXeXqXqXrX>X).uX7XjXp.u s *.jX8XqXqX7.@.*.&.",
"&.&.*.O.[.yX8X0X9X8X8X8X8X8XwX&X_.tX7X8X8X8X8X9X0X9XeX:X(.tX5XdXF.    r.jX5X0X9X7.@.*.&.",
"&.&.=.o.XXhXyXiXiXiXiXiXiXuXdX<X|.gXyXiXiXiXiXiXiXuXsX4X[.gXeXcXF.    r.nXrXiXuX8.@.*.&.",
"&.&.*.+.K.XX[.{.{.{.{.{.{.{. XQ.H.XX{.{.{.{.{.{.{.{. X^.D.XX'.%Xp.    *.*X'.}.{.3.#.*.&.",
"&.&.&.&.+.o.O.O.O.O.O.O.O.O.o.+.@.o.O.O.O.O.O.O.O.O.o.O.@.o.O.O...[ [ ..O.o.O.O.%.&.&.&.",
"&.&.&.&.*.=.*.*.*.*.*.*.*.*.*.*.*.=.*.*.*.*.*.*.*.*.*.*.*.=.*.*.=.-.-.=.*.*.*.*.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.%.%.&.&.&.&.&.&.&.&.&.",
"&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&."
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"&.&.+.O.+.+.+.+.+.+.+.@.O.+.+.+.+.+.+.O.@.+.+.+.+.+.+.+.O.+.&.&.",
"&.&.q.t.r.r.e.r.r.r.e.8.t.r.r.r.r.r.r.t.8.e.r.r.r.r.r.r.t.q.&.&.",
"&.&.>XiXwXtXsXtXeXyX8X XiXrXrXrXrXrXeXiX X8XyXrXrXrXrXrXiX,X&.&.",
"&.&.;XeXuXqXoXwXyXqX5X{.rX0X0XqXqXqX0XrX{.4XwX0XqXqX0X0XrX-X&.&.",
"&.&.-XsX Xj . z @XiX3X{.tX0XqXwXwXwXqXyX}.6XrXwXwXwXqX0XtX;X&.&.",
";.` q s >   X   ! hX2X{.eXpX(.9 u u u i w y u u u 6 T.aXwX;X&.&.",
":.^       . O   N fX3X{.wXsXT.                      D.fXwX;X&.&.",
"*.+.N.^.0..     N.fX2X{.wXaXW.  5 L.P.Y.k.G.I.U.e   J.dXwX;X&.&.",
"%.*.6XfXbX'   | zX8X4X{.wXaXW.  w pXdXhX@XtXfXhXd   H.sXqX-X&.&.",
"&.&.:XeXzX$.  =.cXeX9X XuXhX^.  q qXeXyX}.6XrXyXs   P.kXuX<X&.&.",
"&.&.{.%X5X'   } 6X#XOXE.&X<XS.  8 #X&X=XE.OX&X=Xu   b.2X&X{.&.&.",
"&.&.].#X3X'   } 4X@XoXR.%X>XZ.  0 +X$X&XR.oX%X&Xu   v.<X$X].&.&.",
"&.&.<XyXcX@.  &.vXrX9X.XuXjX_.  < pXtXpX.X9XuXpXs   P.kXuX<X&.&.",
"&.&.-X0XhXo.  #.jX8X4X{.wXiXn.' { [.yXwX{.4XqXeXa   H.sXqX-X&.&.",
"&.&.;XqXjXO.  $.kX9X5X[.dX).oXUXUXL.:XiX{.5XwXrXs   J.dXwX;X&.&.",
"&.&.;XqXjXO.  $.kX9X5X[.dXJ.SXJXUX6X(.fX[.5XwXrXs   J.dXwX;X&.&.",
"&.&.;XqXjXO.  $.kX9X5X[.dX~.*XUXUXT.*XpX{.5XwXrXs   J.dXwX;X&.&.",
"&.&.;XqXjXO.  $.kX9X5X{.rXyXb.1.:.).uXeX{.5XwXrXs   J.dXwX;X&.&.",
"&.&.:XwXkXO.  $.lX0X6X}.eXdX^.  > tXqXtX}.6XeXtXs   J.fXeX:X&.&.",
"&.&.&X7XdXX.  @.fX5X1X'.8XyXY.  e 4X7X0X'.1X8X0Xa   F.iX8X&X&.&.",
"&.&.!.[.%X/   ` &X'._.J.{.OXv.  6 '.{.|.J._.{.}.t   f.@X{.!.&.&.",
"&.&.>XrXzX+.  $.lX0X6X}.eXsXQ.  q qXrXuX|.7XrXiXa   I.gXtX>X&.&.",
"&.&.-X0XhXO.  *.mXuXwXOXaXlX(.  0 8X0XrX{.3XrX7Xh o M.hXqX-X&.&.",
"&.&.;XqXjXO.  ` #X_./.Z.].XXc.  q 9XqXrX{.5XrXS.wXDXP.+XaX-X&.&.",
"&.&.;XqXjX{                     5 9XqXrX[.wX.X#XUXUXVXJ.dX=X&.&.",
"&.&.;XqXhX*.O 4 1 1 < > 1 1 2 - h 9XqXrX{.qX@X{.UXUXzXK.dX=X&.&.",
"&.&.;XtXqX6X2X3X2X4X:X(.6X2X3X2X3XqX0XtX{.4XuXK.].6XB.>XiX-X&.&.",
"&.&.=XeX8XqXwXwXwXeX6X}.tXqXwXwXqX9X8XeX[.3XqXeXe   A.gX9X=X&.&.",
"&.&.3XfXiXpXiXiXiXaXwXXXdXuXiXiXiXpXiXfXoXwXaXdXs   Y.xXaX3X&.&.",
"&.&.J.!.E.E.E.E.E.W.Y.V.!.E.E.E.E.E.E.!.V.U.W.Q.g . u.).W.J.&.&.",
"&.&.o.X.X.X.X.X.X.X.X.O.X.X.X.X.X.X.X.X.O.X.X.X.$.&.O.X.X.o.&.&.",
"&.&.=.=.=.=.=.=.=.=.=.*.=.=.=.=.=.=.=.=.*.=.=.=.*.&.=.=.=.=.&.&."
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"&.1.4.2.<.2.4.3.1.4.3.4.4.3.4.1.3.4.3.4.3.4.3.*.",
"#.}.6X7XaXwX4X4X}.6X5X2X2X1X5X|.*X4X1X2X4X7X<X3.",
"#.1XBX;Xs.].sX0XOXrXwXhXzXkXbX4XpXcXlXzXyXrX7X4.",
"O.,.i.p   + ).uX.XwXwXk.6.w.r.,.7.e.q.7.%XuX4X3.",
"|       %   e.jX|.wXtX9                 Y.fX3X4.",
"+.N._.J   w %XeX.XqXyXi 7 !.W.B.G.[.|   ~.dX3X3.",
"#.;XZX'.  0.nX7XOXrXpXe t zXkX<XqXSXw.  /.hX5X4.",
"#.'.rXI.  <.uX:X[.3X7Xw q 4X3X{.@XuX,.  Y.eX-X3.",
"$.!.2XS.  *.3XXXQ.#X*Xw w *X%X/.[.5X*.  S.,X X1.",
"#.@XcX(.  7.cX0X+XyXfX3 3 dXiX%X2XbX7.  (.kX7X4.",
"#.XXjX!.  5.kX5X.XyX_.).(.).pX+X>XlX4.  ~.dX2X3.",
"#.oXjX~.  5.kX6X+X3X}.UXUX{.5X%X>XzX5.  ~.fX3X4.",
"#.oXjX~.  5.kX6XoXqX~.IXPX!.eX#X>XzX5.  ~.fX3X4.",
"#.oXjX!.  5.kX6XXXtX>X! Q >XiX@X>XzX5.  ~.dX3X3.",
"#.OXlX^.  6.zX7XOXwXsX3 3 sXtX$X<XcX6.  ^.gX4X4.",
"$.E.>XC.  %.,X}.R.oX#Xq q #X+XQ.`.<X&.  C.-X[.1.",
"#.XXhXQ.  3.fX2X|.8XwXw e rXeX+X;XxX1.  ^.sX1X3.",
"#.oXkX~.  e.AXpX;XhXxXy e uXtX#X2XuXa.) K.sX4X4.",
"#.oXkXE.  w G C n Z D   t tXrX+X8X`.fXUX-X@XqX3.",
"#.oXjX~.: - @ # @ # $ % B rXrX+X8X(.CXUX0X XwX2.",
"#.OXyX7X<X3X4X2X{.5X4X1X3X9XrX+X3X3XZ.G.K.eX4X3.",
"#.%XdXyXpXpXpXuX%XaXpXpXpXyXaX*X3XVX2.  ).xX8X4.",
"$.!.%XOXOXOX+XoXW.+XOXOXOXOX$X^.].2X;.  S.;X|.1.",
"&.$.#.#.#.#.#.#.$.#.#.#.#.#.#.$.#.#.O.| @.#.#.&."
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"&.2.8.q.6.5.7.5.4.4.2.4.4.7.6.*.",
":.rXtX;XtX%X4XuXjXfX9XkXdXeX=X;.",
"O.>.C % ^.3XeXL.:.;.#.>.9.1X2X-.",
" .K 7   F.3XfXI - T A F   `.6X=.",
"=.xXB.i hX$XjXY 5.FX0XhXq `.7X=.",
"*.*Xd.p 5X'.0XZ { 7X'.+X3 I.%X=.",
"*.wXn.a dX%XaX .8.sX=X7X5 _.7X=.",
"*.wXn.a dX>XXXGXcX@X1X6X5 _.7X=.",
"*.rXm.s gX:X<X}.|.4X,X8X6 '.8X=.",
"*.7Xx.p tXXXsXV  .dX@X1X8 ^.1X=.",
"*.,Xg.s tXoXiXI +.qX X-X@ U.-X=.",
"*.tXM.q -XW.,XB *.zX;X,Xe.XX4X-.",
"*.7XJ.@ 5 1 6 o e.sX$X+XUX4X#X>.",
";.4XuX3X5X+X1X4XwXrX3X4X#.XX9X-.",
"-.`.@X@X$X'.+X#X+X X_..X, G..X*.",
"&.#.@.+.+.@.@.+.@.#.#.@.&.#.#.&."
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
